# ``KMAdvertisement``
广告Framework，远程控制广告显示，可通过以下参数控制
* 显示状态
* 开始结束时间
* APP名称
* 订阅情况
* 平台
* 支持版本


## 如何接入
* 导入KMAdvertisement.framework
* 导入AFNetworking.framework
* 导入Kingfisher.framework
* <a href="#接入示例"> 按照接入示例</a>

## 功能
* 视图显示模式
  * <a href="#List">List</a>
    * ![](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638caf19f0f171670164249.png)
  * <a href="#View">View</a>
    * ![](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638cb6f268c291670166258.png)
    * ![](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638cb31fbdfc41670165279.png)
  * <a href="#Scroll">Scroll</a>
    * ![](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638cb31fbf94b1670165279.png)
  * <a href="#Pop">Pop(暂未实现)</a>
  
  
* 物件支持
  * 多语
  * 黑暗模式
  * 视图圆角，边框
  * 选中与非选中状态
  * 背景色
  * 跳转指定URL
  * tips

## <a id="接入示例">接入示例</a>
####SDK导入
![导入](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b781b41cea91672970676.png)

#### 视图加载方法
##### 1.绑定视图
![添加方法一](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638ca544dc92c1670161732.png)

##### 2.指定视图
![添加方法二](https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/638ca570776ea1670161776.png)

```swift
// Do any additional setup after loading the view.
//设置基础参数
KMAdvertisementManager.manager.initConfig(appName: .FilmageEditorMac,
                                          subscribeType: .unsubscribed,
                                          platform: .Mac)
//测试模式，默认false
KMAdvertisementManager.manager.debug = true

unowned let weakSelf = self
//获取广告数据
KMAdvertisementManager.manager.fetchData { data, error in
    if data != nil {
        for model in data! {
            if model.showType == .list {
                //视图加载方法一
                let view = KMAdvertisementManager.manager.show(type: KMAdvertisementShowType.list, data: model, superView: weakSelf.showListView) { actionType, actionItem in
                    print("list 1")
                    if actionItem.actionType == .URL {
                        let string = KMAdvertisementModelTransition.transitionLanguage(langeuage: actionItem.linkURL)
                        if NSWorkspace.shared.open(URL.init(string: string)!) {
                            NSWorkspace.shared.open(URL.init(string: string)!)
                        }
                    } else {
                        let string = KMAdvertisementModelTransition.transitionLanguage(langeuage: actionItem.linkURL)
                        if NSWorkspace.shared.open(URL.init(string: string)!) {
                            NSWorkspace.shared.open(URL.init(string: string)!)
                        }
                    }
                }
                
                //视图加载方法二
                weakSelf.tableView.inputData = model
                weakSelf.tableView.actionCompletion = {actionType, actionItem in
                    print("list 2")
                }
            }
            
            if model.showType == .view {
                //视图加载方法一
                let view =  KMAdvertisementManager.manager.show(type: KMAdvertisementShowType.view, data: model, superView: weakSelf.showView) { actionType, actionItem in
                    print("view 1")
                }
                
                //视图加载方法二
                weakSelf.advertisementView.inputData = model
                weakSelf.advertisementView.actionCompletion = {actionType, actionItem in
                    print("view 2")
                }
            }
        }
    }
}
```

### 数据格式
##### KMAdvertisementModel
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| appName   | <a href="#AppNameType"> AppNameType</a>   | appName: FilmageEditorMac |  APP名称
| platform  | <a href="#PlatformType"> PlatformType</a> | platform: iOS             |  平台
| showType  | <a href="#ShowType"> ShowType</a>         | showType: "List"          |  APP名称
| subscribeType | <a href="#SubscribeType"> SubscribeType</a> | subscribeType: "subscribed" |  显示类型
| startTime | String 时间戳                              | startTime: "1669709056569"|  APP名称
| endTime   | String 时间戳                              | endTime: "1709709056569 " |  结束时间
| version   | String                                    | appName: "1.3.5"          | 版本
| content   | <a href="#Section"> Section</a>           | content: [Section]         |  内容


###### <a id="Section">Section</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| sectionTitle | <a href="#Text"> Text</a>              | sectionTitle: <a href="#Text"> Text</a> | setion标题 |
| content  | <a href="#Conent"> Conent</a> | content: [<a href="#Conent"> Conent</a>] | 详情 | 

###### <a id="Content">Content</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| index     | Int                                       | index: 0                  |  下标
| title     | <a href="#Text"> Text</a>                 | title: <a href="#Text"> Text</a> | 标题 |
| imageURL  | <a href="#Image"> Image</a>               | imageURL: <a href="#Image"> Image</a> | 图片链接 |
| ipadImageURL | <a href="#Image"> Image</a>            | ipadImageURL: <a href="#Image"> Image</a> | ipad图片链接 |
| linkURL   | <a href="#Language"> Language</a>         | linkURL: <a href="#Language"> Language</a> | 点击链接 |
| tips      | <a href="#Language"> Language</a>         | tips: <a href="#Language"> Language</a> | tips |
| button    | <a href="#Text"> Text</a>                 | button: <a href="#Text"> Text</a> | 按钮样式 |
| actionType| <a href="#ActionType"> ActionType</a>     | actionType: "URL"         |  响应类型 |

###### <a id="Text">Text</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| font      | <a href="#Font"> Font</a>                 | font: <a href="#Font"> Font</a>  | 字体 |
| color     | <a href="#Color"> Color</a>               | color: <a href="#Color"> Color</a> | 颜色 |
| background | <a href="#Background"> Background</a>    | background: <a href="#Background"> Background</a> | 背景 |
| language  | <a href="#Language"> Language</a>         | language: <a href="#Language"> Language</a> | 多语 |

###### <a id="Image">Image</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| height | <a href="#Language"> Language</a>            | height: <a href="#Language"> Language</a> | 高亮 |
| normal | <a href="#Language"> Language</a>            | normal: <a href="#Language"> Language</a> | 正常 |
| background | <a href="#Background"> Background</a>    | background: <a href="#Background"> Background</a> | 背景颜色 |

###### <a id="Language">Language</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| en        | String                                    | en: "en"                  |  英文
| zh_TW     | String                                    | zhTW: "繁中"               |  繁中
| zh_CN     | String                                    | zhCN: "简中"               |  简中

###### <a id="Background">Background</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| color     | <a href="#Color"> Color</a>               | color:<a href="#Color"> Color</a> |  颜色  |
| layer     | <a href="#Layer"> Layer</a>               | layer:<a href="#Color"> Color</a> |  图层  |

###### <a id="Color">Color</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| height | <a href="#AppNameType"> AppNameType</a>   | appName: FilmageEditorMac |  APP名称
| normal  | <a href="#Conent"> Conent</a> | platform: iOS             |  平台

###### <a id="ColorState">ColorState</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| dark      | <a href="#ColorInfo"> ColorInfo</a>       | dark:{"hex":"#C7C8CC","alpha":1} | 黑暗模式 |
| universal | <a href="#ColorInfo"> ColorInfo</a>       | universal:{"hex":"#C7C8CC","alpha":1} | 正常模式 |

##### <a id="ColorInfo">ColorInfo</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| hex       | String                                    | hex: "#FFFFFF"            | 颜色16进制     |
| alpha     | Float                                     | alpha: 1.0                |  透明度

###### <a id="Font">Text</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| name      | String                                    | name: "AppleSystemUIFont" | 字体名称       |
| size      | Int                                       | size: 13                  | 字体大小       |

###### <a id="Layer">Layer</a>
|     key   |                    type                   |          example          |  description  |
| --------- | ----------------------------------------- | ------------------------- | ------------- |
| cornerRadius | Float                                  | cornerRadius: 15          |  圆角          |
| borderWidth | Float                                   | borderWidth: 1            |  边框宽度       |
| borderColor | <a href="#Color"> Color</a>             | borderColor: <a href="#Color"> Color</a> |  颜色 |


#### json数据
##### <a id="List">List</a>

###### json示例
```json
{
    "appName":6,
    "platform":1,
    "showType":1,
    "version":"1.3.5",
    "startTime":"1669709056569",
    "endTime":"1689709056569",
    "subscribeType":1,
    "content":[
        {
            "sectionTitle":{
                "font":{
                    "name":"AppleSystemUIFont",
                    "size":13
                },
                "color":{
                    "height":{
                        "dark":{
                            "hex":"#C7C8CC",
                            "alpha":1
                        },
                        "universal":{
                            "hex":"#42464D",
                            "alpha":1
                        }
                    },
                    "normal":{
                        "dark":{
                            "hex":"#C7C8CC",
                            "alpha":1
                        },
                        "universal":{
                            "hex":"#42464D",
                            "alpha":1
                        }
                    }
                },
                "language":{
                    "en":"PDF Pro Series",
                    "zh_TW":"PDF Pro系列",
                    "zh_CN":"PDF Pro系列"
                }
            },
            "content":[
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Windows",
                            "zh_TW":"Windows",
                            "zh_CN":"Windows"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "tips":{
                        "en":"Get Latest PDF Reader Pro for Windows ",
                        "zh_TW":"獲取PDF Reader Pro Windows版本",
                        "zh_CN":"获取最新PDF Reader Pro Windows版本"
                    },
                    "actionType":1,
                    "hidden":true,
                    "imageURL":{
                        "height":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1925221a5c1672581714.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1925221a5c1672581714.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1925221a5c1672581714.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1925221a5c1672581714.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1925221a5c1672581714.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1925221a5c1672581714.pdf"
                            }
                        },
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b22c44ab1e41672621124.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b22c44ab1e41672621124.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b22c44ab1e41672621124.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b22c44ab1e41672621124.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b22c44ab1e41672621124.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b22c44ab1e41672621124.pdf"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/windows?utm_source=MacApp&amp;utm_campaign=PDFProMac&amp;utm_medium=pdfmac_promo",
                        "zh_TW":"https://www.pdfreaderpro.com/windows?utm_source=MacApp&amp;utm_campaign=PDFProMac&amp;utm_medium=pdfmac_promo",
                        "zh_CN":"https://www.pdfreaderpro.com/windows?utm_source=MacApp&amp;utm_campaign=PDFProMac&amp;utm_medium=pdfmac_promo"
                    }
                },
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"iPhone,iPad",
                            "zh_TW":"iPhone,iPad",
                            "zh_CN":"iPhone,iPad"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "tips":{
                        "en":"Get PDF Reader Pro for iOS",
                        "zh_TW":"獲取PDF Reader Pro iOS版本",
                        "zh_CN":"获取最新PDF Reader Pro iOS版本"
                    },
                    "actionType":1,
                    "imageURL":{
                        "height":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a769fa1672579738.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a769fa1672579738.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a769fa1672579738.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a7f3441672579738.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a7f3441672579738.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a7f3441672579738.pdf"
                            }
                        },
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a760571672579738.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a760571672579738.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a760571672579738.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a760571672579738.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a760571672579738.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b18a9a760571672579738.pdf"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/product?utm_source=MacAppDmg&amp;utm_campaign=ProductLinkLeftNav&amp;utm_medium=PdfProduct",
                        "zh_TW":"https://www.pdfreaderpro.com/product?utm_source=MacAppDmg&amp;utm_campaign=ProductLinkLeftNav&amp;utm_medium=PdfProduct",
                        "zh_CN":"https://www.pdfreaderpro.com/product?utm_source=MacAppDmg&amp;utm_campaign=ProductLinkLeftNav&amp;utm_medium=PdfProduct"
                    }
                },
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Android",
                            "zh_TW":"Android",
                            "zh_CN":"Android"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "tips":{
                        "en":"Get PDF Reader Pro for Android",
                        "zh_TW":"獲取PDF Reader Pro Android版本",
                        "zh_CN":"获取最新PDF Reader Pro Android版本"
                    },
                    "actionType":1,
                    "hidden":true,
                    "imageURL":{
                        "height":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b191573f28a1672581463.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b191573f28a1672581463.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b191573f28a1672581463.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b191573f28a1672581463.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b191573f28a1672581463.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b191573f28a1672581463.pdf"
                            }
                        },
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1904e1b8281672581198.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1904e1b8281672581198.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1904e1b8281672581198.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1904e1b8281672581198.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1904e1b8281672581198.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b1904e1b8281672581198.pdf"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/pdfreaderpro-android?utm_source=MacAppDmg&amp;utm_campaign=AndroidLink&amp;utm_medium=PdfAndroid",
                        "zh_TW":"https://www.pdfreaderpro.com/pdfreaderpro-android?utm_source=MacAppDmg&amp;utm_campaign=AndroidLink&amp;utm_medium=PdfAndroid",
                        "zh_CN":"https://www.pdfreaderpro.com/pdfreaderpro-android?utm_source=MacAppDmg&amp;utm_campaign=AndroidLink&amp;utm_medium=PdfAndroid"
                    }
                }
            ]
        },
        {
            "sectionTitle":{
                "font":{
                    "name":"AppleSystemUIFont",
                    "size":13
                },
                "color":{
                    "height":{
                        "dark":{
                            "hex":"#C7C8CC",
                            "alpha":1
                        },
                        "universal":{
                            "hex":"#42464D",
                            "alpha":1
                        }
                    },
                    "normal":{
                        "dark":{
                            "hex":"#C7C8CC",
                            "alpha":1
                        },
                        "universal":{
                            "hex":"#42464D",
                            "alpha":1
                        }
                    }
                },
                "language":{
                    "en":"Other",
                    "zh_TW":"其它",
                    "zh_CN":"其它"
                }
            },
            "content":[
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"ComPDFKit",
                            "zh_TW":"ComPDFKit",
                            "zh_CN":"ComPDFKit"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "hidden":true,
                    "actionType":1,
                    "tips":{
                        "en":"First-rate PDF SDK Library for Developers",
                        "zh_TW":"ComPDFKit PDF SDK軟體工具開發包",
                        "zh_CN":"ComPDFKit PDF SDK软件开发工具包"
                    },
                    "imageURL":{
                        "height":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf"
                            }
                        },
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f151672725029.pdf"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://www.compdf.com?utm_source=macapp&utm_medium=pdfmac&utm_campaign=compdfkit-promp",
                        "zh_TW":"https://www.compdf.com?utm_source=macapp&utm_medium=pdfmac&utm_campaign=compdfkit-promp",
                        "zh_CN":"https://www.compdf.com?utm_source=macapp&utm_medium=pdfmac&utm_campaign=compdfkit-promp"
                    }
                },
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"ComVideoKit",
                            "zh_TW":"ComVideoKit",
                            "zh_CN":"ComVideoKit"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "hidden":true,
                    "actionType":1,
                    "tips":{
                        "en":"ComVideoKit Video SDK Library for Developers",
                        "zh_TW":"ComVideoKit Video SDK軟體工具開發包",
                        "zh_CN":"ComVideoKit Video SDK软件开发工具包"
                    },
                    "imageURL":{
                        "height":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf"
                            }
                        },
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c225a7f171672725029.pdf"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://www.filmagepro.com/video-sdk?utm_source=macapp&utm_medium=pdfmac&utm_campaign=comvideosdk-promo",
                        "zh_TW":"https://www.filmagepro.com/video-sdk?utm_source=macapp&utm_medium=pdfmac&utm_campaign=comvideosdk-promo",
                        "zh_CN":"https://www.filmagepro.com/video-sdk?utm_source=macapp&utm_medium=pdfmac&utm_campaign=comvideosdk-promo"
                    }
                },
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"eSignFlow Editor",
                            "zh_TW":"eSignFlow Editor",
                            "zh_CN":"eSignFlow Editor"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "actionType":1,
                    "tips":{
                        "en":"Fast &amp; light eSign PDF Editor lets you read, annotate, edit, esign PDF documents anytime.",
                        "zh_TW":"SignFlow電子簽名工具支援數字簽署PDF文檔、創建並填寫Form、編輯、閱讀、註釋PDF文檔，輕鬆解決您的文檔需求。",
                        "zh_CN":"SignFlow电子签名工具支持数字签署PDF文档、创建并填写form、编辑、阅读、注释PDF文档，轻松解决您的文档需求！"
                    },
                    "imageURL":{
                        "height":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png"
                            }
                        },
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4eecea1672622276.png"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://apps.apple.com/app/apple-store/id1584624017?pt=118745145&amp;ct=pdfmac-promo&amp;mt=8",
                        "zh_TW":"https://apps.apple.com/app/apple-store/id1584624017?pt=118745145&amp;ct=pdfmac-promo&amp;mt=8",
                        "zh_CN":"https://apps.apple.com/app/apple-store/id1584624017?pt=118745145&amp;ct=pdfmac-promo&amp;mt=8"
                    }
                },
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Filmage Editor",
                            "zh_TW":"Filmage Editor",
                            "zh_CN":"Filmage Editor"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "actionType":1,
                    "tips":{
                        "en":"Make video editing simplified! Create fantastic videos and share with Filmage Editor anytime.",
                        "zh_TW":"簡化視頻編輯，創建精彩視頻，並一鍵分享您的大作！",
                        "zh_CN":"简化视频编辑，创建出精彩的视频，并一键分享您的大作！"
                    },
                    "imageURL":{
                        "height":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062093ff1672622178.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062093ff1672622178.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062093ff1672622178.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062093ff1672622178.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062093ff1672622178.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062093ff1672622178.png"
                            }
                        },
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062383f71672622178.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062383f71672622178.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062383f71672622178.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062383f71672622178.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062383f71672622178.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23062383f71672622178.pdf"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://apps.apple.com/app/apple-store/id1475051178?pt=118745145&amp;ct=pdfmac-promo&amp;mt=8",
                        "zh_TW":"https://apps.apple.com/app/apple-store/id1475051178?pt=118745145&amp;ct=pdfmac-promo&amp;mt=8",
                        "zh_CN":"https://apps.apple.com/app/apple-store/id1475051178?pt=118745145&amp;ct=pdfmac-promo&amp;mt=8"
                    }
                },
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Filmage Screen",
                            "zh_TW":"Filmage Screen",
                            "zh_CN":"Filmage Screen"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "actionType":1,
                    "tips":{
                        "en":"Complete screen &amp; audio recorder and basic editing tool on Mac. ",
                        "zh_TW":"集錄屏、錄音、編輯、轉換於一身的屏幕錄製軟體。高清錄製，場景編輯！",
                        "zh_CN":"集录屏、录音、编辑、转换于一身的屏幕录制软件。高清录制，场景编辑！"
                    },
                    "imageURL":{
                        "height":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png"
                            }
                        },
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b230c4e66621672622276.png"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://apps.apple.com/app/apple-store/id1475049179?pt=118745145&amp;ct=pdfmac-promo&amp;mt=8",
                        "zh_TW":"https://apps.apple.com/app/apple-store/id1475049179?pt=118745145&amp;ct=pdfmac-promo&amp;mt=8",
                        "zh_CN":"https://apps.apple.com/app/apple-store/id1475049179?pt=118745145&amp;ct=pdfmac-promo&amp;mt=8"
                    }
                },
                {
                    "title":{
                        "font":{
                            "name":"AppleSystemUIFont",
                            "size":13
                        },
                        "color":{
                            "height":{
                                "dark":{
                                    "hex":"#4E7EDB",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#273B61",
                                    "alpha":1
                                }
                            },
                            "normal":{
                                "dark":{
                                    "hex":"#C7C8CC",
                                    "alpha":1
                                },
                                "universal":{
                                    "hex":"#42464D",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Free PDF Templates",
                            "zh_TW":"免費PDF模板",
                            "zh_CN":"免费PDF模板"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":0.05
                                    },
                                    "universal":{
                                        "hex":"#000000",
                                        "alpha":0.05
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#25282B",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FBFCFF",
                                        "alpha":0.05
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":6
                            }
                        }
                    },
                    "imageURL":{
                        "height":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a3582a1672622378.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a3582a1672622378.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a3582a1672622378.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a3582a1672622378.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a3582a1672622378.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a3582a1672622378.pdf"
                            }
                        },
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a2e9c51672622378.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a2e9c51672622378.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a2e9c51672622378.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a2e9c51672622378.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a2e9c51672622378.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b2312a2e9c51672622378.pdf"
                            }
                        }
                    },
                    "actionType":1,
                    "hidden":true,
                    "tips":{
                        "en":"Free PDF Templates",
                        "zh_TW":"免費PDF模板",
                        "zh_CN":"免费PDF模板"
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/templates?utm_source=MacApp&amp;utm_campaign=PDFProMac&amp;utm_medium=pdfmac_promo",
                        "zh_TW":"https://www.pdfreaderpro.com/templates?utm_source=MacApp&amp;utm_campaign=PDFProMac&amp;utm_medium=pdfmac_promo",
                        "zh_CN":"https://www.pdfreaderpro.com/templates?utm_source=MacApp&amp;utm_campaign=PDFProMac&amp;utm_medium=pdfmac_promo"
                    }
                }
            ]
        }
    ]
}
```

#####  <a id="View">View</a>
###### json示例
```json
{
    "appName":6,
    "platform":1,
    "showType":4,
    "version":"1.3.5",
    "startTime":"1669709056569",
    "endTime":"1709709056569",
    "subscribeType":1,
    "content":[
        {
            "content":[
                {
    "productID":"1122",
    "startTime":"1669709056569",
    "endTime":"1709709056569",
                    "imageURL":{
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23c20439d51672625184.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23c20439d51672625184.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23d7d1b89c1672625533.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23c20439d51672625184.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23c20439d51672625184.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b23d7d1b89c1672625533.pdf"
                            }
                        }
                    },
"actionType":1,
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/store",
                        "zh_TW":"https://www.pdfreaderpro.com/store",
                        "zh_CN":"https://www.pdfreaderpro.com/store"
                    }
                },{
    "productID":"1123",
    "startTime":"1669709056569",
    "endTime":"1709709056569",
                    "imageURL":{
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c3959fc321672725397.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c3959fc321672725397.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c3958a5d51672725397.pdf"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c3959fc321672725397.pdf",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c3959fc321672725397.pdf",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b3c3958a5d51672725397.pdf"
                            }
                        }
                    },
"actionType":1,
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/store",
                        "zh_TW":"https://www.pdfreaderpro.com/store",
                        "zh_CN":"https://www.pdfreaderpro.com/store"
                    }
                }
            ]
        }
    ]
}
```

#####  <a id="Scroll">Scroll</a>
###### json示例
```json
{
    "appName":18,
    "platform":2,
    "showType":3,
    "version":"1.3.5",
    "startTime":"1669709056569",
    "endTime":"1700709056569",
    "subscribeType":1,
    "content":[
        {
            "content":[
                {
                    "actionType":1,
                    "productID":"2022010601",
                    "title":{
                        "font":{
                            "name":"Helvetica-Bold",
                            "size":20
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"All-New PDF Reader Pro Windows Released!",
                            "zh_TW":"PDF Reader Pro Windows版全新發佈！",
                            "zh_CN":"PDF Reader Pro Windows版全新发布！"
                        }
                    },
                    "button":{
                        "font":{
                            "name":"PingFangSC-Semibold",
                            "size":13
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Learn More",
                            "zh_TW":"更多資訊",
                            "zh_CN":"了解更多"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":15,
                                "borderWidth":1,
                                "borderColor":{
                                    "color":{
                                        "height":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        },
                                        "normal":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "imageURL":{
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa67781672888543.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa67781672888543.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa67781672888543.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa67781672888543.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa67781672888543.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa67781672888543.png"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/windows?utm_source=iOSApp&amp;utm_campaign=PDFiOS&amp;utm_medium=pdfios_promo",
                        "zh_TW":"https://www.pdfreaderpro.com/windows?utm_source=iOSApp&amp;utm_campaign=PDFiOS&amp;utm_medium=pdfios_promo",
                        "zh_CN":"https://www.pdfreaderpro.com/windows?utm_source=iOSApp&amp;utm_campaign=PDFiOS&amp;utm_medium=pdfios_promo"
                    }
                },
                {
                    "actionType":2,
                    "productID":"2022010602",
                    "title":{
                        "font":{
                            "name":"Helvetica-Bold",
                            "size":20
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Get PDF Reader Pro Permanent License",
                            "zh_TW":"解鎖進階版PDF Reader Pro",
                            "zh_CN":"解锁PDF Reader Pro高级版"
                        }
                    },
                    "button":{
                        "font":{
                            "name":"PingFangSC-Semibold",
                            "size":13
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Upgrade Now",
                            "zh_TW":"即刻升級",
                            "zh_CN":"立即升级"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":15,
                                "borderWidth":1,
                                "borderColor":{
                                    "color":{
                                        "height":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        },
                                        "normal":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "imageURL":{
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa64141672888543.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa64141672888543.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa64141672888543.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa64141672888543.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa64141672888543.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa64141672888543.png"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://www.pdfreaderpro.com/windows?utm_source=iOSApp&amp;utm_campaign=PDFiOS&amp;utm_medium=pdfios_promo",
                        "zh_TW":"https://www.pdfreaderpro.com/windows?utm_source=iOSApp&amp;utm_campaign=PDFiOS&amp;utm_medium=pdfios_promo",
                        "zh_CN":"https://www.pdfreaderpro.com/windows?utm_source=iOSApp&amp;utm_campaign=PDFiOS&amp;utm_medium=pdfios_promo"
                    }
                },
                {
                    "actionType":1,
                    "productID":"2022010503",
                    "title":{
                        "font":{
                            "name":"Helvetica-Bold",
                            "size":20
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Fast & Light eSignFlow PDF Editor",
                            "zh_TW":"輕便快捷的SignFlow電子簽名軟體。",
                            "zh_CN":"轻便快捷的SignFlow电子签名软件。"
                        }
                    },
                    "button":{
                        "font":{
                            "name":"PingFangSC-Semibold",
                            "size":13
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Free Download",
                            "zh_TW":"免費下載",
                            "zh_CN":"免费下载"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":15,
                                "borderWidth":1,
                                "borderColor":{
                                    "color":{
                                        "height":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        },
                                        "normal":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "imageURL":{
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa967f1672888543.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa967f1672888543.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa967f1672888543.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa967f1672888543.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa967f1672888543.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b640dfa967f1672888543.png"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://apps.apple.com/app/apple-store/id1584624017?pt=118745145&ct=proios-promo&mt=8",
                        "zh_TW":"https://apps.apple.com/app/apple-store/id1584624017?pt=118745145&ct=proios-promo&mt=8",
                        "zh_CN":"https://apps.apple.com/app/apple-store/id1584624017?pt=118745145&ct=proios-promo&mt=8"
                    }
                },
                {
                    "actionType":1,
                    "productID":"2022010604",
                    "title":{
                        "font":{
                            "name":"Helvetica-Bold",
                            "size":20
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"ComPDFkit PDF SDK Library for Developers",
                            "zh_TW":"ComPDFkit PDF SDK軟體工具開發包",
                            "zh_CN":"ComPDFkit PDF SDK软件开发工具包"
                        }
                    },
                    "button":{
                        "font":{
                            "name":"PingFangSC-Semibold",
                            "size":13
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Learn More",
                            "zh_TW":"更多資訊",
                            "zh_CN":"了解更多"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":15,
                                "borderWidth":1,
                                "borderColor":{
                                    "color":{
                                        "height":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        },
                                        "normal":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "imageURL":{
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d30ea81672888733.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d30ea81672888733.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d30ea81672888733.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d30ea81672888733.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d30ea81672888733.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d30ea81672888733.png"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://www.compdf.com/?utm_source=iOSApp&utm_medium=pdfios&utm_campaign=promo",
                        "zh_TW":"https://www.compdf.com/?utm_source=iOSApp&utm_medium=pdfios&utm_campaign=promo",
                        "zh_CN":"https://www.compdf.com/?utm_source=iOSApp&utm_medium=pdfios&utm_campaign=promo"
                    }
                },
                {
                    "actionType":1,
                    "productID":"2022010505",
                    "title":{
                        "font":{
                            "name":"Helvetica-Bold",
                            "size":20
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"ComVideoKit Video SDK Library for Developers",
                            "zh_TW":"ComVideoKit Video SDK軟體工具開發包",
                            "zh_CN":"ComVideoKit Video SDK软件开发工具包"
                        }
                    },
                    "button":{
                        "font":{
                            "name":"PingFangSC-Semibold",
                            "size":13
                        },
                        "color":{
                            "normal":{
                                "universal":{
                                    "hex":"#FFFFFF",
                                    "alpha":1
                                }
                            }
                        },
                        "language":{
                            "en":"Learn More",
                            "zh_TW":"更多資訊",
                            "zh_CN":"了解更多"
                        },
                        "background":{
                            "color":{
                                "height":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                },
                                "normal":{
                                    "dark":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    },
                                    "universal":{
                                        "hex":"#FFFFFF",
                                        "alpha":1
                                    }
                                }
                            },
                            "layer":{
                                "cornerRadius":15,
                                "borderWidth":1,
                                "borderColor":{
                                    "color":{
                                        "height":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        },
                                        "normal":{
                                            "dark":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            },
                                            "universal":{
                                                "hex":"#FFFFFF",
                                                "alpha":1
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    },
                    "imageURL":{
                        "normal":{
                            "dark":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d2f6db1672888733.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d2f6db1672888733.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d2f6db1672888733.png"
                            },
                            "universal":{
                                "en":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d2f6db1672888733.png",
                                "zh_TW":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d2f6db1672888733.png",
                                "zh_CN":"https://pdfreader-dev.oss-cn-shanghai.aliyuncs.com/advertise/63b6419d2f6db1672888733.png"
                            }
                        }
                    },
                    "linkURL":{
                        "en":"https://www.filmagepro.com/video-sdk?utm_source=pdfios&utm_medium=pdfios&utm_campaign=promo",
                        "zh_TW":"https://www.filmagepro.com/video-sdk?utm_source=pdfios&utm_medium=pdfios&utm_campaign=promo",
                        "zh_CN":"https://www.filmagepro.com/video-sdk?utm_source=pdfios&utm_medium=pdfios&utm_campaign=promo"
                    }
                }
            ]
        }
    ]
}
```

#####  <a id="Pop">Pop</a>
###### json示例
```
```

#### 代码块
* <a id="AppNameType">KMAdvertisementAppNameType</a>
```swift
//APP类型
@objc public enum KMAdvertisementAppNameType: Int, Codable {
    case RecordIt = 0
    case RecordItPro = 1
    case RecordItDMG = 2
    case FilmageScreen = 3
    case FilmageScreenPro = 4
    case FilmageScreenDMG = 5
    case FilmageEditorMac = 6
    case FilmageEditorMacPro = 7
    case FilmageEditorMacDMG = 8
    case FilmageConverterMac = 9
    case FilmageConverterMacPro = 10
    case FilmageConverterMacDMG = 11
    case FilmagePlayerMac = 12
    case FilmagePlayerMacPro = 13
    case FilmagePlayerMacDMG = 14
    case PDFReaderProMac = 15
    case PDFReaderProMacPro = 16
    case PDFReaderProMacDMG = 17
    case PDFReaderProIOS = 18
    case PDFReaderProIOSPro = 19
}
```

* <a id="PlatformType">KMAdvertisementPlatformType</a>
```swift
//平台
public enum KMAdvertisementPlatformType: String, Codable {
    case unknow = "unknow"
    case Mac = "Mac" //
    case iOS = "iOS" //
}
```

* <a id="ShowType">KMAdvertisementShowType</a>
```swift
//显示样式
public enum KMAdvertisementShowType: String, Codable {
    case unknow = 0
    case list = 1 //列表
    case pop = 2 //弹窗
    case scroll = 3 //循环
    case view = 4 //视图显示
}
```


* <a id="SubscribeType">KMAdvertisementSubscribeType</a>
```swift
//订阅状态
public enum KMAdvertisementSubscribeType: String, Codable {
    case unknow = 0
    case unsubscribed = 1 //未订阅
    case subscribed = 2 //已订阅
    case all = 3 //无限制
}

```

* <a id="ActionType">KMAdvertisementActionType</a>
```swift
//点击视图后跳转选项
public enum KMAdvertisementActionType: String, Codable {
    case unknow = 0
    case URL = 1 //链接
    case comparative = 2 //比价表
}
```

* <a id="LanguageType">KMAdvertisementLanguageType</a>
```swift
//多语
public enum KMAdvertisementLanguageType: String {
    case unknow = "unknow"
    case en = "en"//
    case zhCN = "zhCN"//
    case zhTW = "zhTW"//
}

```
